@@ -473,12 +473,12 @@ def clean_mxtype_using_dictionary(df,mx_bv_dict,mx_prob_dict):
 
 def create_new_position_flag(df,days):
     if 'DaysSincePositionStart' in df:
-        logging.info('Days Since position detected, creating flag and deleting the column')
+        logging.info(f'Days Since position detected, creating flag for {days} days')
         df['DaysSincePositionStart'].fillna(999)
-        df['new_position'] = 0
-        df.loc[df['DaysSincePositionStart']< days,'new_position'] = 1
-        df.drop('DaysSincePositionStart',inplace=True,axis=1)
-        logging.info(f'{df.new_position.value_counts()}')
+        colname = 'new_position_'+str(days)
+        df[colname] = 0
+        df.loc[df['DaysSincePositionStart']< days,colname] = 1
+        logging.info(f'{df.colname.value_counts()}')
     else:
-        logging.info('Column not found, no changes were made.')
+        logging.info(' dayssincepositionstart Column not found, no changes were made.')
     return df
